"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.detectFileInclusion = detectFileInclusion;
const FILE_INCLUSION_PATTERNS = [
    /\binclude\b.*\bhttp:\/\//i, // Inclusión remota de archivos usando HTTP
    /\binclude\b.*\bftp:\/\//i, // Inclusión remota de archivos usando FTP
    /\bphp:\/\/input\b/, // Flujo de entrada de PHP
    /\bdata\b:text\/plain;base64,/, // Datos codificados en Base64
    /expect:\/\//, // Protocolo expect
    /phar:\/\//, // Protocolo phar
    /\bini_set\b/i, // Función ini_set
    /\bopen_basedir\b/i, // Función open_basedir
    /\bload_file\b/i, // Función load_file
    /\binto\b\s+\boutfile\b/i, // Sintaxis INTO OUTFILE
    /\bfile:\/\/\b/, // Protocolo file
    /\bphp:\/\/\b/, // Protocolo PHP
    /<\?php/i, // Etiqueta de apertura de PHP
    /data:.*?base64,/, // Datos codificados en Base64
    /expect:\/\//i, // Protocolo expect
    /phar:\/\//i, // Protocolo phar
    /\bfile_put_contents\b/i, // Función file_put_contents
    /\bexec\b/i, // Función exec
    /\bsystem\b/i, // Función system
    /\bshell_exec\b/i, // Función shell_exec
    /\bpopen\b/i, // Función popen
    /\bproc_open\b/i, // Función proc_open
];
/**
 * Detects if there is a potential file inclusion vulnerability in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential file inclusion vulnerability is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common file inclusion patterns in the input string.
 * Patterns include directory traversal, remote file inclusion, and access to sensitive files and directories.
 *
 * @example
 * ```typescript
 * const input = "../../etc/passwd";
 * const isFileInclusion = detectFileInclusion(input);
 * console.log(isFileInclusion); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
function detectFileInclusion(input) {
    return FILE_INCLUSION_PATTERNS.some((pattern) => pattern.test(input));
}
//# sourceMappingURL=fileInclusionDetector.js.map