/**
 * Checks if a given string contains a potentially dangerous SQL statement.
 *
 * @param input - The string to check.
 * @returns `true` if a potentially dangerous SQL statement is detected, otherwise `false`.
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export declare function isSQLSentence(input: string): boolean;
/**
 * Detects if there is a potential SQL injection in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential SQL injection is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a regular expression to look for common SQL injection patterns in the input string.
 * Patterns include SQL keywords like SELECT, UPDATE, DELETE, INSERT, DROP, UNION, AND, OR, as well as two or more digit numbers and the pattern '; --'.
 *
 * @example
 * ```typescript
 * const input = "SELECT * FROM users WHERE id = 1; --";
 * const isSQLInjection = detectSQLInjection(input);
 * console.log(isSQLInjection);  // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export declare function detectSQLInjection(input: string): boolean;
